@@ -1,7 +1,7 @@
 """SDR Receiver Wrapper"""
 from argparse import ArgumentDefaultsHelpFormatter
 from . import config, defs, util
-import subprocess, logging, textwrap
+import subprocess, logging, textwrap, os
 logger = logging.getLogger(__name__)
 
 
@@ -37,7 +37,7 @@ def _tune_max_pipe_size(pipesize):
         return True
 
 
-def _check_apps(tsp_disabled=False):
+def _check_apps(tsp_disabled, bindir):
     """Check if required apps are installed"""
     try:
         subprocess.check_output(["which", "rtl_sdr"])
@@ -45,24 +45,18 @@ def _check_apps(tsp_disabled=False):
         logging.error("Couldn't find rtl_sdr. Is it installed?")
         return False
 
-    try:
-        subprocess.check_output(["which", "leandvb"])
-    except subprocess.CalledProcessError:
+    if (not os.path.isfile(os.path.join(bindir, "leandvb"))):
         logging.error("Couldn't find leandvb. Is it installed?")
         return False
 
-    try:
-        subprocess.check_output(["which", "ldpc_tool"])
-    except subprocess.CalledProcessError:
+    if (not os.path.isfile(os.path.join(bindir, "ldpc_tool"))):
         logging.error("Couldn't find ldpc_tool. Is it installed?")
         return False
 
     if (tsp_disabled):
         return True
 
-    try:
-        subprocess.check_output(["which", "tsp"])
-    except subprocess.CalledProcessError:
+    if (not os.path.isfile(os.path.join(bindir, "tsp"))):
         logging.error("Couldn't find tsp. Is it installed?")
         return False
 
@@ -81,7 +75,7 @@ def subparser(subparsers):
                        help='Samples per symbol, or, equivalently, the '
                            'target oversampling ratio')
     rtl_group = rtl_p.add_mutually_exclusive_group()
-    rtl_group.add_argument('-g', '--gain', default=30, type=float,
+    rtl_group.add_argument('-g', '--gain', default=40, type=float,
                            help='RTL-SDR Rx gain')
     rtl_group.add_argument('-f', '--iq-file', default=None,
                            help='File to read IQ samples from instead of reading '
@@ -109,8 +103,6 @@ def subparser(subparsers):
                         help="Choose low-throughput vs high-throughput MODCOD")
     ldvb_p.add_argument('--ldpc-dec', default="ext", choices=["int", "ext"],
                         help="LDPC decoder to use (internal or external)")
-    ldvb_p.add_argument('--ldpc-tool', default="/usr/local/bin/ldpc_tool",
-                        help='Path to ldpc_tool')
     ldvb_p.add_argument('--ldpc-bf', default=100,
                         help='Max number of iterations used by the internal \
                         LDPC decoder when not using an external LDPC tool')
@@ -135,7 +127,7 @@ def subparser(subparsers):
     tsp_p.add_argument('--max-input-packets', default=10, type=int,
                        help='Maximum number of packets received at a time from '
                        'the tsp input plugin ')
-    tsp_p.add_argument('-p', '--bitrate-period', default=10, type=int,
+    tsp_p.add_argument('-p', '--bitrate-period', default=1, type=int,
                        help='Period of bitrate reports in seconds')
     tsp_p.add_argument('-l', '--local-address', default="127.0.0.1",
                        help='IP address of the local interface on which to '
@@ -177,11 +169,17 @@ def run(args):
     if (info is None):
         return
 
+    bindir = os.path.join(args.cfg_dir, "usr", "bin")
+
     pipe_size_bytes = int(args.pipe_size * (2**20))
     if (not _tune_max_pipe_size(pipe_size_bytes)):
         return
 
-    if (not _check_apps(tsp_disabled=(args.no_tsp or args.record))):
+    if (not _check_apps((args.no_tsp or args.record), bindir)):
+        print("\nTo install software dependencies, run:")
+        print("""
+        blocksat-cli deps install
+        """)
         return
 
     # Demodulator configs
@@ -221,7 +219,8 @@ def run(args):
         else:
             rtl_cmd.append("-")
 
-    ldvb_cmd = ["leandvb", "--nhelpers", str(args.n_helpers), "-f",
+    ldvb_path = os.path.join(bindir, "leandvb")
+    ldvb_cmd  = [ldvb_path, "--nhelpers", str(args.n_helpers), "-f",
                 str(samp_rate), "--sr", str(sym_rate), "--roll-off",
                 str(defs.rolloff), "--standard", "DVB-S2", "--sampler", "rrc",
                 "--rrc-rej", str(args.rrc_rej), "--modcods", modcod,
@@ -232,7 +231,8 @@ def run(args):
     elif (args.debug_ts > 1):
         ldvb_cmd.extend(["-d", "-d"])
     if (args.ldpc_dec == "ext"):
-        ldvb_cmd.extend(["--ldpc-helper", args.ldpc_tool,
+        ldpc_tool_path = os.path.join(bindir, "ldpc_tool")
+        ldvb_cmd.extend(["--ldpc-helper", ldpc_tool_path,
                          "--ldpc-iterations", str(args.ldpc_iterations)])
     else:
         ldvb_cmd.extend(["--ldpc-bf", str(args.ldpc_bf)])
@@ -248,10 +248,11 @@ def run(args):
     ldvb_stderr = None if (args.debug_ts > 0) else subprocess.DEVNULL
 
     # Input
-    tsp_cmd = ["tsp", "--realtime", "--buffer-size-mb",
-               str(args.buffer_size_mb), "--max-flushed-packets",
-               str(args.max_flushed_packets), "--max-input-packets",
-               str(args.max_input_packets)]
+    tsp_path = os.path.join(bindir, "tsp")
+    tsp_cmd  = [tsp_path, "--realtime", "--buffer-size-mb",
+                str(args.buffer_size_mb), "--max-flushed-packets",
+                str(args.max_flushed_packets), "--max-input-packets",
+                str(args.max_input_packets)]
     # MPEG-TS Analyzer
     if (args.analyze):
         print("MPEG-TS analysis will be saved on file {}".format(
